📝 Changelog
+++++++++++++

..
    scriv-insert-here

.. _unreleased:

Unreleased
==========

.. _changelog-0.3.0:

0.3.0 - 2022-12-21
==================

✨ Added
--------

* Added support for custom path filters to config object

.. _changelog-0.2.0:

0.2.0 — 2022-12-20
==================

✨ Added
--------
* Added basic templates for workflow and config files
* Added additional Project metadata

🔧 Changed
----------
* Updated dependencies
* Migrate project to exasol organization

📚 Documentation
----------------
* Updated workflow documentation


0.1.0 — 2022-11-25
==================

✨ Initial release
